@@ -2,7 +2,7 @@ package Outthentic::DSL;
 
 use strict;
 
-our $VERSION = '0.1.3';
+our $VERSION = '0.1.4';
 
 use Carp;
 use Data::Dumper;
@@ -361,8 +361,11 @@ sub validate {
         }
 
         if ($l=~ /^\s*assert:\s(\S+)\s+(.*)$/) {
-            $self->add_debug_result("assert found: $1,$2") if $self->{debug_mod} >= 2;
-            $self->add_result({ status => $1 , message => $2 });
+            my $status = $1; my $message = $2;
+            $self->add_debug_result("assert found: $status , $message") if $self->{debug_mod} >= 2;
+            $status = 0 if $status eq 'false'; # ruby to perl conversion
+            $status = 1 if $status eq 'true'; # ruby to perl conversion
+            $self->add_result({ status => $status , message => $message });
             next LINE;
         }
 
@@ -539,7 +542,7 @@ sub handle_code {
               }
 
             }else{
-              $ext_runner.= ' '.$self->{languages}->{$language} if $self->{languages}->{$language};
+              $ext_runner = $self->{languages}->{$language} if $self->{languages}->{$language};
               $ext_runner.=' '.$source_file;
             }
 
@@ -670,7 +673,7 @@ sub handle_generator {
                 }
   
               }else{
-                $ext_runner.= ' '.$self->{languages}->{$language} if $self->{languages}->{$language};
+                $ext_runner = $self->{languages}->{$language} if $self->{languages}->{$language};
                 $ext_runner.=' '.$source_file;
               }
   
@@ -1521,7 +1524,7 @@ Updated check list:
     again
 
 If you use not Perl in generator expressions, you have to print entries into stdout instead of returning
-and array reference like in Perl. Here is more examples for other languages:
+an array reference like in Perl. Here are some generators examples for other languages:
 
     generator: <<CODE
     !bash
